@@ -43,13 +43,20 @@ def poll_form(instance, request):
     
     coffee.construct_widgets(form.fields, placeholders, must_delete=False)
     
+    placeholders = {
+        'choice_text': 'Choice'
+    }
+    
+    for formset_form in formset:
+        coffee.construct_widgets(formset_form.fields, placeholders, must_delete=False)
+    
     return {'form': form, 'formset': formset}
 
 
 @register.inclusion_tag('polls/partial/vote.html')
 def poll_vote(instance):
     form = get_poll_vote_form(instance)
-
+    
     return {'form': form, 'instance': instance}
 
 
