@@ -12,6 +12,7 @@ from polls.models import Choice, Poll, UserChoice, AnonymousUserChoice
 from polls.forms import PollForm, PollVoteForm
 from polls.methods import get_poll_form, get_poll_vote_form
 
+from coffee.mixins import FormMixin
 
 class PollListView(ListView):
     template_name = 'polls/index.html'
@@ -142,7 +143,7 @@ class PollVoteView(FormView):
         return context
 
 
-class PollView(FormView):
+class PollView(FormView, FormMixin):
     form_class = PollForm
     template_name = 'polls/poll/poll.html'
 
